/* 
	Nagios-Cacti Unified Reporting Dashboard (NURD)
	
	Copyright 2010 Nicholas Watts <nwatts4@une.edu.au>
	
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	MA 02110-1301, USA.
*/

var nagios_cgi = "https://monitor.organisation.com/cgi-bin/nagios3";
var nagios_root = "https://monitor.organisation.com/nagios3";
var cacti_root = "https://monitor.organisation.com/cacti";
var nurd_root = "https://monitor.organisation.com/cacti/plugins/nurd";

var loading_message = "<span style=\"font-weight:bold;font-size:1.0em;\">Loading...</span>";

function scrape_nagios_data(data)
{
	var temp = "";
	temp = data.split(/<div align=center class='reportTime'>\[.+?\]<\/div>\n<BR><BR>\n/mg);
	data = temp;
	temp = data[1]; // only want stuff after the generation time
	data = temp.replace(/href=["'](.+?)["']/mgi, "href=\""+nagios_cgi+"/$1\"");
	data = data.replace(/src=["'](.+?)["']/mgi, "src=\""+nagios_cgi+"/$1\"");
	temp = data.split(/<\/body>/mgi);
	data = temp[0]; // don't include the closing body and html tags

	var service_index = data.search(/<DIV ALIGN=CENTER CLASS='dataTitle'>State Breakdowns For Host Services:<\/DIV>/mg);
	var log_index = data.search(/<DIV ALIGN=CENTER CLASS='dataTitle'>Host Log Entries:<\/DIV>/mg);
	
	host_data = data.substr(0,service_index);
	service_data = data.substr(service_index, log_index-service_index);
	log_data = data.substr(log_index);
	
	var styleinfo = "<LINK REL='stylesheet' TYPE='text/css' HREF='"+nagios_root+"/stylesheets/common.css'><LINK REL='stylesheet' TYPE='text/css' HREF='"+nagios_root+"/stylesheets/avail.css'>";
	
	return styleinfo+"<div id=\"nagios_host_data\">"+host_data+"</div><div id=\"nagios_service_data\">"+service_data+"</div><div id=\"nagios_log_data\">"+log_data+"</div>";
}

function generate_html_report(container_id, host_id, hostname, starttime, endtime, show_host, show_services, show_trends, show_logs)
{
	var content = "";
	var show_log_entries = ""
	
	var start_d = new Date(starttime*1000);
	var end_d = new Date(endtime*1000);
	
	content += "<style>"
	if (!show_host) {
		content += "#nagios_host_data { display:none; }\n";
	}
	if (!show_services) {
		content += "#nagios_service_data { display:none; }\n";
	}
	if (!show_trends) {
		content += "#cacti_report { display:none; }\n";
	}
	if (!show_logs) {
		content += "#nagios_log_data { display:none; }\n";
	}
	content += "</style>";
	
	content += "<div class=\"report_heading\">";
	content += hostname+"</div>";
	content += "<div class=\"report_date\"><span class=\"report_label\">Starting:</span> "+start_d+"<br />";
	content += "<span class=\"report_label\">Finishing:</span> "+end_d+"</div><hr />";
	content += "<div id=\"nagios_report\" class=\"nagios_report\"></div><hr />";
	content += "<div id=\"cacti_report\" class=\"cacti_report\"></div>";
	
	document.getElementById(container_id).innerHTML = content;
	pagedata(nagios_cgi+"/avail.cgi?host="+hostname+"&timeperiod=custom&smon="+(start_d.getMonth()+1)+"&sday="+start_d.getDate()+"&syear="+start_d.getFullYear()+"&shour="+start_d.getHours()+"&smin="+start_d.getMinutes()+"&ssec="+start_d.getSeconds()+"&emon="+(end_d.getMonth()+1)+"&eday="+end_d.getDate()+"&eyear="+end_d.getFullYear()+"&ehour="+end_d.getHours()+"&emin="+end_d.getMinutes()+"&esec="+end_d.getSeconds()+"&show_log_entries", "nagios_report", 0, "nagios");
	// if not matching server was found in the cacti database, cacti_host_lookup.php returns -1
	if (host_id > -1) {
		pagedata(nurd_root+"/cacti_report.php?host_id="+host_id+"&graph_start="+starttime+"&graph_end="+endtime, "cacti_report", 0, null);
	}
}

function pagedata(url, container_id, append, scrape_type)
{
    var request = null;
	if (window.XMLHttpRequest) // Firefox, Chrome, Safari
	{
		request=new XMLHttpRequest();
	}

	else if (window.ActiveXObject) // IE
	{
		request=new ActiveXObject("Microsoft.request");
	}
	if (request!=null)
	{
		request.onreadystatechange=function () {
			if (request.readyState == 4 && request.status == 200)
			{
				var data = request.responseText;
				if (scrape_type == "nagios")
				{
					data = scrape_nagios_data(data);
				}
				if (!append)
				{
					document.getElementById(container_id).innerHTML = data;
				}
				else
				{
					document.getElementById(container_id).innerHTML = document.getElementById(container_id).innerHTML + data;
				}
			}
		};
		request.open("GET",url,true);
		
		request.send(null);
		document.getElementById(container_id).innerHTML = loading_message;
	}
	else
	{
		alert("Error: your browser does not support AJAX.\nTry Mozilla Firefox, Google Chrome.");
	}
}
