/* 
	Nagios-Cacti Unified Reporting Dashboard (NURD)
	
	Copyright 2010 Nicholas Watts <nwatts4@une.edu.au>
	
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	MA 02110-1301, USA.
*/

function lookup_cacti_host()
{
	var hostname = document.report_form.nagios_hostname.value;
	var request = null;
	if (window.XMLHttpRequest) // Firefox, Chrome, Safari
	{
		request=new XMLHttpRequest();
	}

	else if (window.ActiveXObject) // IE
	{
		request=new ActiveXObject("Microsoft.request");
	}
	if (request!=null)
	{
		request.onreadystatechange=function () {
			if (request.readyState == 4 && request.status == 200)
			{
				var data = request.responseText;
				var id = data.split("|")[0];
				var cacti_hostname = data.split("|")[1];
				document.getElementById("cacti_hostname").innerHTML = cacti_hostname;
				document.report_form.cacti_host_id.value = id;
			}
		};
		document.getElementById("cacti_hostname").innerHTML = "Querying Database...";
		request.open("GET",nurd_root+"/cacti_host_lookup.php?hostname="+hostname,true);
		request.send(null);
	}
	else
	{
		alert("Error: your browser does not support AJAX.\nTry Mozilla Firefox, Google Chrome.");
	}
}

function span_changed()
{
	var span = document.report_form.report_span.options[document.report_form.report_span.selectedIndex].value;
	if (span == "custom")
	{
		document.getElementById("custom_span").style.display = "block";
	}
	else
	{
		document.getElementById("custom_span").style.display = "none";
	}
}

function calculate_timestamps(span_type)
{
	if (span_type == "lasthour")
	{
		start_timestamp = new Date();
		start_timestamp.setHours(start_timestamp.getHours()-1);
		start_timestamp = start_timestamp.getTime()/1000;
		end_timestamp = new Date().getTime()/1000;
	}
	else if (span_type == "lastday")
	{
		start_timestamp = new Date();
		start_timestamp.setDate(start_timestamp.getDate()-1);
		start_timestamp = start_timestamp.getTime()/1000;
		end_timestamp = new Date().getTime()/1000;
	}
	else if (span_type == "lastweek")
	{
		start_timestamp = new Date();
		start_timestamp.setDate(start_timestamp.getDate()-7);
		start_timestamp = start_timestamp.getTime()/1000;
		end_timestamp = new Date().getTime()/1000;
	}
	else if (span_type == "lastmonth")
	{
		start_timestamp = new Date();
		start_timestamp.setDate(start_timestamp.getDate()-31);
		start_timestamp = start_timestamp.getTime()/1000;
		end_timestamp = new Date().getTime()/1000;
	}
	else if (span_type == "lastyear")
	{
		start_timestamp = new Date();
		start_timestamp.setDate(start_timestamp.getDate()-365);
		start_timestamp = start_timestamp.getTime()/1000;
		end_timestamp = new Date().getTime()/1000;
	}
	else if (span_type == "financialyear")
	{
		start_timestamp = new Date();
		if (start_timestamp.getMonth() >= 6) // this year's july
		{
			start_timestamp = new Date("July 1 "+start_timestamp.getFullYear());
		}
		else // last year's july
		{
			start_timestamp = new Date("July 1 "+(start_timestamp.getFullYear()-1));
		}
		start_timestamp = start_timestamp.getTime()/1000;
		end_timestamp = new Date().getTime()/1000;
	}
	else
	{
		return [-1,-1]; // definitely an error!
	}
	
	return [Math.round(start_timestamp), Math.round(end_timestamp)];
}
	
// function validates form input and converts human-readable 
// dates/times to Cacti/RRDtool timestamps
function format_timestamps()
{
	var span_type = document.report_form.report_span.options[document.report_form.report_span.selectedIndex].value;
	var start_timestamp = "";
	var end_timestamp = "";
	
	if (span_type == "custom")
	{
		var datestr = document.report_form.graph_start_date.value + " " + document.report_form.graph_start_time.value;
		var start_timestamp = new Date(datestr).getTime()/1000;
		if (!start_timestamp)
		{
			alert("Start date/time is not valid, please enter a valid date and time.");
			return false;
		}
		start_timestamp = Math.round(start_timestamp);
		datestr = document.report_form.graph_end_date.value + " " + document.report_form.graph_end_time.value;
		end_timestamp = new Date(datestr).getTime()/1000;
		if (!end_timestamp)
		{
			alert("End date/time is not valid, please enter a valid date and time.");
			return false;
		}
		end_timestamp = Math.round(end_timestamp);
	}
	
	else
	{
		stamps = calculate_timestamps(span_type);
		start_timestamp = stamps[0];
		end_timestamp = stamps[1];
	}
	
	if (start_timestamp > end_timestamp)
	{
		alert("Error: start time is later than end time.");
		return false;
	}
	
	document.report_form.graph_start.value = start_timestamp;
	document.report_form.graph_end.value = end_timestamp;
	return true;
}

// function runs the input form validation checks and creates a html 
// preview of the report if the data looks ok.
function html_preview(container_id)
{
	if (format_timestamps())
	{
		// generate_html_report() is defined in html_report.js
		var starttime = document.report_form.graph_start.value;
		var endtime = document.report_form.graph_end.value;
		var host_id = document.report_form.cacti_host_id.value;
		var hostname = document.report_form.nagios_hostname.options[document.report_form.nagios_hostname.selectedIndex].value;
		var show_host = "no";
		var bool_host = false;
		if (document.report_form.show_host.checked) { show_host = "yes"; bool_host = true;}
		var show_services = "no";
		var bool_services = false;
		if (document.report_form.show_services.checked) { show_services = "yes"; bool_services = true;}
		var show_trends = "no";
		var bool_trends = false;
		if (document.report_form.show_trends.checked) { show_trends = "yes"; bool_trends = true;}
		var show_logs = "no";
		var bool_logs = false;
		if (document.report_form.show_logs.checked) { show_logs = "yes"; bool_logs = true;}
		if (container_id != "")
		{
			generate_html_report(container_id, host_id, hostname, starttime, endtime, bool_host, bool_services, bool_trends, bool_logs);
		}
		else
		{
			var span_type = document.report_form.report_span.options[document.report_form.report_span.selectedIndex].value;
			var timespan = "";
			if (span_type == "custom")
			{
				timespan = "&starttime="+starttime+"&endtime="+endtime;
			}
			else
			{
				timespan = "&timespan="+span_type;
			}
			window.open("report.php?cacti_host_id="+host_id+"&nagios_hostname="+hostname+timespan+"&show_host="+show_host+"&show_services="+show_services+"&show_trends="+show_trends+"&show_logs="+show_logs);
		}
	}
}
